==> haskell-rsa-2.3.0-15-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-rsa.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: RSA
version: 2.3.0
id: RSA-2.3.0-sZWn5oaryGIc5SeevRWDP
key: RSA-2.3.0-sZWn5oaryGIc5SeevRWDP
license: BSD-3-Clause
maintainer: Adam Wick <awick@galois.com>
author: Adam Wick <awick@galois.com>
stability: stable
synopsis: Implementation of RSA, using the padding schemes of PKCS#1 v2.1.
description:
    This library implements the RSA encryption and signature
    algorithms for arbitrarily-sized ByteStrings. While the
    implementations work, they are not necessarily the fastest ones
    on the planet. Particularly key generation. The algorithms
    included are based of RFC 3447, or the Public-Key Cryptography
    Standard for RSA, version 2.1 (a.k.a, PKCS#1 v2.1).
category: Cryptography, Codec
abi: acab270174ba8fb28d7a0acd82858d31
exposed: True
exposed-modules:
    Codec.Crypto.RSA Codec.Crypto.RSA.Exceptions Codec.Crypto.RSA.Pure
import-dirs: /usr/lib/ghc-8.4.3/site-local/RSA-2.3.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/RSA-2.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/RSA-2.3.0
hs-libraries: HSRSA-2.3.0-sZWn5oaryGIc5SeevRWDP
depends:
    base-4.11.1.0 binary-0.8.5.1 bytestring-0.10.8.2
    crypto-api-0.13.3-8kwytB5sSk41kEhPI2rwwJ
    crypto-pubkey-types-0.4.3-7nKwcudCogv3F8xLXU7OIO
    SHA-1.6.4.4-J97i4k52krALB5u9VxmQ73
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             binary-0.8.5.1=0c28e4e382bf1405fd468e0d2a2b58e5
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             crypto-api-0.13.3-8kwytB5sSk41kEhPI2rwwJ=ce10e49cbca1b74596de9d427ce328a8
             crypto-pubkey-types-0.4.3-7nKwcudCogv3F8xLXU7OIO=655d0032c0a158a748db2cf66ac6bd79
             SHA-1.6.4.4-J97i4k52krALB5u9VxmQ73=7fdfeaf1e3416ffd434c90cf824fb303
haddock-interfaces: /usr/share/doc/haskell-rsa/html/RSA.haddock
haddock-html: /usr/share/doc/haskell-rsa/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-rsa-2.3.0-24-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-rsa.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: RSA
version: 2.3.0
id: RSA-2.3.0-5muPoYEidN16dwAGGlH2c8
key: RSA-2.3.0-5muPoYEidN16dwAGGlH2c8
license: BSD-3-Clause
maintainer: Adam Wick <awick@galois.com>
author: Adam Wick <awick@galois.com>
stability: stable
synopsis: Implementation of RSA, using the padding schemes of PKCS#1 v2.1.
description:
    This library implements the RSA encryption and signature
    algorithms for arbitrarily-sized ByteStrings. While the
    implementations work, they are not necessarily the fastest ones
    on the planet. Particularly key generation. The algorithms
    included are based of RFC 3447, or the Public-Key Cryptography
    Standard for RSA, version 2.1 (a.k.a, PKCS#1 v2.1).
category: Cryptography, Codec
abi: d0fd243c557f6dea2ab8a875c55caf35
exposed: True
exposed-modules:
    Codec.Crypto.RSA Codec.Crypto.RSA.Exceptions Codec.Crypto.RSA.Pure
import-dirs: /usr/lib/ghc-8.4.3/site-local/RSA-2.3.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/RSA-2.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/RSA-2.3.0
hs-libraries: HSRSA-2.3.0-5muPoYEidN16dwAGGlH2c8
depends:
    base-4.11.1.0 binary-0.8.5.1 bytestring-0.10.8.2
    crypto-api-0.13.3-9u8sDwmn8dvFreHHUkKG0l
    crypto-pubkey-types-0.4.3-21qB40pgZ9ypx8jkhkukE
    SHA-1.6.4.4-J97i4k52krALB5u9VxmQ73
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             binary-0.8.5.1=0c28e4e382bf1405fd468e0d2a2b58e5
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             crypto-api-0.13.3-9u8sDwmn8dvFreHHUkKG0l=04b47272348e9aa5648e546d18028ecd
             crypto-pubkey-types-0.4.3-21qB40pgZ9ypx8jkhkukE=446d92453474bdf3db9af71b4f8ecc8d
             SHA-1.6.4.4-J97i4k52krALB5u9VxmQ73=7fdfeaf1e3416ffd434c90cf824fb303
haddock-interfaces: /usr/share/doc/haskell-rsa/html/RSA.haddock
haddock-html: /usr/share/doc/haskell-rsa/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
